import numpy as np

from mu_map.file.convert import dicom_to_interfile
from mu_map.file.dicom import is_dicom, load_dcm, load_dcm_img
from mu_map.file.interfile import load_interfile, load_interfile_img, Interfile


def load_as_interfile(filename: str) -> Interfile:
    """
    Load a file as an Interfile image even if it is
    in DICOM format.

    :param filename: the file to be loaded in Interfile format
    :return: an Interfile image
    """
    if is_dicom(filename):
        return dicom_to_interfile(*load_dcm(filename))
    else:
        return load_interfile(filename)


def load_img(filename: str) -> np.ndarray:
    """
    Load a file as a numpy array.

    :param filename: the file to be loaded
    :return: a numpy array of the image
    """
    if is_dicom(filename):
        return load_dcm_img(filename)
    else:
        return load_interfile_img(filename)
